translate.lang.vi.vi

Package translate :: Package lang :: Module vi :: Class vi |
[hide private]
[frames] | no frames]

# Class vi

source code

This class represents Vietnamese.

Instance Methods | [hide private]
Inherited from `common.Common`: `__deepcopy__`, `__repr__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Methods | [hide private]
punctranslate(cls, text) Implement some extra features for quotation marks. | source code
Inherited from `common.Common`: `alter_length`, `capsstart`, `character_iter`, `characters`, `length_difference`, `sentence_iter`, `sentences`, `word_iter`, `words`

Static Methods | [hide private]
Inherited from `common.Common`: `__new__`

Class Variables | [hide private]
| puncdict = ``{``u'``!``'``:` `u'``!``'``,` `u'``#``'``:` `u'``#``'``,` `u'``:``'``:` `u'``:``'``,` `u'``;``'``:` `u'``;``'``}`` A dictionary of punctuation transformation rules that can be used by punctranslate().
| c = ``u'``#``'``
Inherited from `common.Common`: `CJKpunc`, `checker`, `code`, `commonpunc`, `ethiopicpunc`, `fullname`, `ignoretests`, `indicpunc`, `invertedpunc`, `listseperator`, `miscpunc`, `nplurals`, `pluralequation`, `punctuation`, `quotes`, `rtlpunc`, `sentenceend`, `sentencere`, `validaccel`, `validdoublewords` Inherited from `common.Common` (private): `_languages`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### punctranslate(cls, text) Class Method | source code
Implement some extra features for quotation marks. Known shortcomings: % and $ are not touched yet for fear of variables Double spaces might be introduced Overrides: common.Common.punctranslate